@@ -1,15 +1,17 @@
+# -*- coding: utf-8 -*-
+
+from __future__ import unicode_literals
+
 import io
+import itertools
 import os
 import re
 
 import jinja2
 import ruamel.yaml
 
-# patch over differences between PY2 and PY3
-try:
-    text_type = unicode
-except NameError:
-    text_type = str
+from conda_build.metadata import ensure_valid_license_family
+
 
 EXPECTED_SECTION_ORDER = ['package', 'source', 'build', 'requirements',
                           'test', 'app', 'about', 'extra']
@@ -19,10 +21,10 @@ REQUIREMENTS_ORDER = ['build', 'run']
 
 class NullUndefined(jinja2.Undefined):
     def __unicode__(self):
-        return text_type(self._undefined_name)
+        return self._undefined_name
 
     def __getattr__(self, name):
-        return text_type('{}.{}'.format(self, name))
+        return '{}.{}'.format(self, name)
 
     def __getitem__(self, name):
         return '{}["{}"]'.format(self, name)
@@ -55,8 +57,12 @@ def lintify(meta, recipe_dir=None):
     section_order_sorted = sorted(major_sections,
                                   key=EXPECTED_SECTION_ORDER.index)
     if major_sections != section_order_sorted:
+        section_order_sorted_str = map(lambda s: "'%s'" % s,
+                                       section_order_sorted)
+        section_order_sorted_str = ", ".join(section_order_sorted_str)
+        section_order_sorted_str = "[" + section_order_sorted_str + "]"
         lints.append('The top level meta keys are in an unexpected order. '
-                     'Expecting {}.'.format(section_order_sorted))
+                     'Expecting {}.'.format(section_order_sorted_str))
 
     # 2: The about section should have a home, license and summary.
     for about_item in ['home', 'license', 'summary']:
@@ -116,6 +122,29 @@ def lintify(meta, recipe_dir=None):
         lints.append('When defining a source/url please add a sha256, sha1 '
                      'or md5 checksum (sha256 preferably).')
 
+    # 10: License should not include the word 'license'.
+    license = about_section.get('license', '').lower()
+    if 'license' in license.lower():
+        lints.append('The recipe `license` should not include the word '
+                     '"License".')
+
+    # 11: There should be one empty line at the end of the file.
+    if recipe_dir is not None and os.path.exists(meta_fname):
+        with io.open(meta_fname, 'r') as f:
+            lines = f.read().split('\n')
+        # Count the number of empty lines from the end of the file
+        empty_lines = itertools.takewhile(lambda x: x == '', reversed(lines))
+        end_empty_lines_count = len(list(empty_lines))
+        if end_empty_lines_count != 1:
+            lints.append('There should be one empty line at the end of the '
+                         'file.')
+
+    # 12: License family must be valid (conda-build checks for that)
+    try:
+        ensure_valid_license_family(meta)
+    except RuntimeError as e:
+        lints.append(str(e))
+
     return lints
 
 
