@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from __future__ import print_function
+from __future__ import print_function, unicode_literals
 from collections import OrderedDict
 from contextlib import contextmanager
 import io
@@ -48,6 +48,15 @@ class Test_linter(unittest.TestCase):
         expected_message = "The recipe license cannot be unknown."
         self.assertIn(expected_message, lints)
 
+    def test_bad_about_license_family(self):
+        meta = {'about': {'home': 'a URL',
+                          'summary': 'A test summary',
+                          'license': 'BSD 3-clause',
+                          'license_family': 'BSD3'}}
+        lints = linter.lintify(meta)
+        expected = "about/license_family 'BSD3' not allowed"
+        self.assertTrue(any(lint.startswith(expected) for lint in lints))
+
     def test_missing_about_home(self):
         meta = {'about': {'license': 'BSD',
                           'summary': 'A test summary'}}
@@ -107,7 +116,7 @@ class Test_linter(unittest.TestCase):
             lints = linter.lintify({}, recipe_dir)
             self.assertIn(expected_message, lints)
 
-            with open(os.path.join(recipe_dir, 'run_test.py'), 'w') as fh:
+            with io.open(os.path.join(recipe_dir, 'run_test.py'), 'w') as fh:
                 fh.write('# foo')
             lints = linter.lintify({}, recipe_dir)
             self.assertNotIn(expected_message, lints)
@@ -118,7 +127,7 @@ class Test_linter(unittest.TestCase):
 
         with tmp_directory() as recipe_dir:
             def assert_selector(selector, is_good=True):
-                with open(os.path.join(recipe_dir, 'meta.yaml'), 'w') as fh:
+                with io.open(os.path.join(recipe_dir, 'meta.yaml'), 'w') as fh:
                     fh.write("""
                             package:
                                name: foo_py2  # [py2k]
@@ -145,7 +154,7 @@ class Test_linter(unittest.TestCase):
         # Test that we can use os.environ in a recipe. We don't care about
         # the results here.
         with tmp_directory() as recipe_dir:
-            with open(os.path.join(recipe_dir, 'meta.yaml'), 'w') as fh:
+            with io.open(os.path.join(recipe_dir, 'meta.yaml'), 'w') as fh:
                 fh.write("""
                         {% set version = os.environ.get('WIBBLE') %}
                         package:
@@ -197,11 +206,50 @@ class Test_linter(unittest.TestCase):
         meta = {'source': {'url': None, 'md5': None}}
         self.assertNotIn(expected_message, linter.lintify(meta))
 
+    def test_redundant_license(self):
+        meta = {'about': {'home': 'a URL',
+                          'summary': 'A test summary',
+                          'license': 'MIT License'}}
+        lints = linter.lintify(meta)
+        expected_message = ('The recipe `license` should not include '
+                            'the word "License".')
+        self.assertIn(expected_message, lints)
+
+    def test_end_empty_line(self):
+        bad_contents = [
+            # No empty lines at the end of the file
+            'extra:\n  recipe-maintainers:\n    - goanpeca',
+            'extra:\r  recipe-maintainers:\r    - goanpeca',
+            'extra:\r\n  recipe-maintainers:\r\n    - goanpeca',
+            # Two empty lines at the end of the file
+            'extra:\n  recipe-maintainers:\n    - goanpeca\n\n',
+            'extra:\r  recipe-maintainers:\r    - goanpeca\r\r',
+            'extra:\r\n  recipe-maintainers:\r\n    - goanpeca\r\n\r\n',
+            # Three empty lines at the end of the file
+            'extra:\n  recipe-maintainers:\n    - goanpeca\n\n\n',
+            'extra:\r  recipe-maintainers:\r    - goanpeca\r\r\r',
+            'extra:\r\n  recipe-maintainers:\r\n    - goanpeca\r\n\r\n\r\n',
+        ]
+        # Exactly one empty line at the end of the file
+        valid_content = 'extra:\n  recipe-maintainers:\n    - goanpeca\n'
+
+        for content in bad_contents + [valid_content]:
+            with tmp_directory() as recipe_dir:
+                with io.open(os.path.join(recipe_dir, 'meta.yaml'), 'w') as f:
+                    f.write(content)
+                lints = linter.lintify({}, recipe_dir=recipe_dir)
+                expected_message = ('There should be one empty line at the '
+                                    'end of the file.')
+                if content == valid_content:
+                    self.assertNotIn(expected_message, lints)
+                else:
+                    self.assertIn(expected_message, lints)
+
 
 class TestCLI_recipe_lint(unittest.TestCase):
     def test_cli_fail(self):
         with tmp_directory() as recipe_dir:
-            with open(os.path.join(recipe_dir, 'meta.yaml'), 'w') as fh:
+            with io.open(os.path.join(recipe_dir, 'meta.yaml'), 'w') as fh:
                 fh.write(textwrap.dedent("""
                     package:
                         name: 'test_package'
@@ -216,7 +264,7 @@ class TestCLI_recipe_lint(unittest.TestCase):
 
     def test_cli_success(self):
         with tmp_directory() as recipe_dir:
-            with open(os.path.join(recipe_dir, 'meta.yaml'), 'w') as fh:
+            with io.open(os.path.join(recipe_dir, 'meta.yaml'), 'w') as fh:
                 fh.write(textwrap.dedent("""
                     package:
                         name: 'test_package'
@@ -240,7 +288,7 @@ class TestCLI_recipe_lint(unittest.TestCase):
 
     def test_cli_environ(self):
         with tmp_directory() as recipe_dir:
-            with open(os.path.join(recipe_dir, 'meta.yaml'), 'w') as fh:
+            with io.open(os.path.join(recipe_dir, 'meta.yaml'), 'w') as fh:
                 fh.write(textwrap.dedent("""
                     package:
                         name: 'test_package'
@@ -270,7 +318,7 @@ class TestCLI_recipe_lint(unittest.TestCase):
         """
         with tmp_directory() as recipe_dir:
             with io.open(os.path.join(recipe_dir, 'meta.yaml'), 'wt') as fh:
-                fh.write(u"""
+                fh.write("""
                     package:
                         name: 'test_package'
                     build:
